@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2002 Mikael Hallendal <micke@imendio.com>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: Mikael Hallendal <micke@imendio.com>
+ * Author: Mikael Hallendal <micke@codefactory.se>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -668,17 +668,17 @@ window_about_cb (gpointer data, guint section, GtkWidget *widget)
 
 	if (about == NULL) {
 		const gchar *authors[] = { 
-			"Mikael Hallendal <micke@imendio.com>",
+			"Mikael Hallendal <micke@codefactory.se>",
 			"Alexander Larsson <alexl@redhat.com>",
 			NULL
 		};
 		/* Note to translators: put here your name (and address) so it
 		 * will shop up in the "about" box */
-		gchar *translator_credits = _("translator_credits");
+		gchar       *translator_credits = _("translator_credits");
 	
 		about = gnome_about_new (PACKAGE, VERSION,
-					 "Copyright 2001-2003 Mikael Hallendal <micke@imendio.com>",
-					 _("Help Browser for GNOME 2.0"),
+					 "Copyright 2001-2002 Mikael Hallendal <micke@codefactory.se>",
+					 _("A Help Browser for GNOME"),
 					 authors,
 					 NULL,
 					 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
@@ -690,7 +690,6 @@ window_about_cb (gpointer data, guint section, GtkWidget *widget)
 				  &about);
 		gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (data));
 	}
-
 	gtk_window_present (GTK_WINDOW (about));
 }
 
